@@ -51,6 +51,7 @@ struct option_data option_list[] = {
   { 'f', "force", { 0 }, { 0 }, 0, ". force execution of the action even when not recommended" },
   { 'U', "user", { "STRING", 0 }, { 0, 0 }, 0, ". privileged user login to revert to if required [default=] NIY" },
   { 'P', "pass", { "STRING", 0 }, { 0, 0 }, 0, ". privileged user password to revert to if required [default=] NIY" },
+  { 'q', "quiet", { 0 }, { 0 }, 0, ". suppress verbose info on standard output" },
   { 'Q', "verbose", { 0 }, { 0 }, 0, ". send verbose info to standard output" },
   { 0, 0, { 0 }, { 0 }, 0, 0 }
 };
@@ -61,7 +62,7 @@ void init_options(struct options* o) {
   o->strip = srcinst_get_pref_strip();
   o->install = srcinst_get_pref_install();
   o->force = 0;
-  o->quiet = 1;
+  o->quiet = srcinst_get_pref_quiet();
   o->src_compress = srcinst_get_pref_src_compress();
   srcinst_init_string_list(&(o->configure_strings));
   srcinst_add_string_list(&o->configure_strings, "./configure");
