@@ -63,7 +63,7 @@ int add_package(char* packagename, char* source) {
     return 0;
   }
 
-  rv = install_package_aux(h, source, 1, 1);
+  rv = install_package_aux(h, source, 1);
   return (srcinst_close_package(h) && rv);
 }
 
@@ -186,7 +186,7 @@ int check_package(char* packagename) {
   return srcinst_close_package(h);
 }
 
-int install_package_aux(SRCINST_PHANDLE h, char* source, int configureq, int check_conflicts) {
+int install_package_aux(SRCINST_PHANDLE h, char* source, int configureq) {
 
   SRCINST_ERR err;
   SRCINST_MFEATS mf; int rv = 0;
@@ -251,7 +251,7 @@ int install_package_aux(SRCINST_PHANDLE h, char* source, int configureq, int che
       goto end_proc;
     }
 
-    if (check_conflicts) {
+    if (1) {			/* check conflicts */
       struct srcinst_string_list conflicts;
       
       if (!srcinst_get_conflict_list(h, &conflicts)) {
@@ -312,7 +312,7 @@ int install_package(char* packagename) {
 		    "source code not available for", packagename);
     rv = 0;
   } else {
-    rv = install_package_aux(h, source, configureq, 1);
+    rv = install_package_aux(h, source, configureq);
   }
 
   return (srcinst_close_package(h) && rv);
@@ -370,13 +370,13 @@ int upgrade_package(char* newname, char* oldname, char* src) {
   
   h = 0; rv = 0;
 
-  if (!(h = srcinst_upgrade_package(oldname, newname))) {
+  if (!(h = srcinst_upgrade_package(newname, oldname))) {
     srcinst_warning(SRCINST_ERR_ACTION, "cannot start upgrade, "
 		    "check package names", 0);
-    goto end_proc;
+    return 0;
   }
 
-  if (!install_package_aux(h, src, 1, 0)) {
+  if (!install_package_aux(h, src, 1)) {
     srcinst_warning(SRCINST_ERR_ACTION, 
 		    "could not install new package version", 0);
     goto end_proc;
@@ -639,6 +639,10 @@ int detect_opts(char* packagename, char* source) {
       printf("Option class: Old-style (2.13) features/packages\n");
       print_option_set(&option_sets.olds);
     }
+    if (option_sets.res1.count > 0) {
+      printf("Option class: uncategorized\n");
+      print_option_set(&option_sets.res1);
+    }
 
     srcinst_free_configure_opt(&option_sets);
   }
